define(["require", "exports"], function (require, exports) {
    function hello() { }
    exports.hello = hello;
});
